
// PortList.java
// Andrew Davison, ad@fivedots.coe.psu.ac.th, November 2010

/* List all the ports available on the local machine. 
   Usage:
     run PortList

*/


import gnu.io.*;
import java.util.*;

public class PortList 
{
  public static void main (String [] args) 
  {
    Enumeration portList = CommPortIdentifier.getPortIdentifiers();
    while (portList.hasMoreElements()) { 
      CommPortIdentifier portId = (CommPortIdentifier)portList.nextElement();

      if (portId.getPortType() == CommPortIdentifier.PORT_SERIAL) {
        System.out.println("Serial port: " + portId.getName());
        try {
          SerialPort port = (SerialPort) portId.open("portList", 1000);   // 1 sec wait 
          System.out.println("  baud: " + port.getBaudRate()  +
                 "; data bits: " + port.getDataBits() +
                 "; flow control: " + port.getFlowControlMode() +
                 "; parity: " + port.getParity() + 
                 "; stop bits: " + port.getStopBits() );
          if (port != null) 
            port.close();
        } 
        catch(PortInUseException e) 
        {  System.out.println("  Port already in use" ); }
      } 
      else if (portId.getPortType () == CommPortIdentifier.PORT_PARALLEL) {
        System.out.println("Parallel port: " + portId.getName());
        try {
          ParallelPort port = (ParallelPort) portId.open("portList", 1000);   // 1 sec wait 
          System.out.println("  " + port);
          if (port != null) 
            port.close();
        } 
        catch(PortInUseException e) 
        {  System.out.println("  Port already in use" ); }
      }
      else
        System.out.println("Other port type: " + portId.getName());
    }
  } // end of main()


} // class PortList