
// GPSTagTests.java
// Andrew Davison, November 2010, ad@fivedots.coe.psu.ac.th

/* Show how to read and write latitude and longitude 
   details from the Exif meta data in a JPEG by 
   using Sanselan (http://commons.apache.org/sanselan/)
   and my support classes, MetaDataUtils and GeoMath

   I used XnView (http://www.xnview.com) to check the EXIF 
   data inside JPEG files separately from this code.

   Usage:
     run GPSTagTests 53.314401 -2.255305 library.jpg
                  // UK address coords
                  // 7.006835 100.5020   // robot building 

*/


public class GPSTagTests
{

  public static void main(String[] args) 
  {
    if (args.length != 3) {
      System.out.println("Usage: run GPSTagTests latitude longitude jpg_file");
      return;
    }

    showGPS(args[2]);

    double lat = Double.parseDouble(args[0]);
    double lon  = Double.parseDouble(args[1]);
    writeGPS(args[2], lat, lon); 
  }  // end of main()



  private static void showGPS(String fnm)
  // print the latitude and longitude info in the file
  {
    double[] coord = MetaDataUtils.getGPSCoord(fnm);
    if (coord != null) {
      System.out.println("GPS data for " + fnm + ":");

      System.out.printf("  Latitude (Degrees North): %.6f\n", coord[0]);
      int[] dms = GeoMath.DDtoDMS(coord[0]);
      System.out.println("    in DMS form: " + dms[0] + " deg " +
                                               dms[1] + "' " +
                                               dms[2] + "''");

      System.out.printf("  Longitude (Degrees East): %.6f\n", coord[1]);
      dms = GeoMath.DDtoDMS(coord[1]);
      System.out.println("    in DMS form: " + dms[0] + " deg " +
                                               dms[1] + "' " +
                                               dms[2] + "''");
      System.out.println();
    }
    else
      System.out.println("No data found");
  }  // end of showGPS()



  private static void writeGPS(String fnm, double lat, double lon)
  // modify the (lat, lon) in fnm, and save changes to a new file
  {
    System.out.printf("\nWriting (lat, lon): (%.6f, %.6f)\n", lat, lon);
    String outFnm = extendFilename(fnm, "NEW");
    System.out.println("Saving changes to " + outFnm);
    boolean hasSucceeded = MetaDataUtils.putGPSInfo(fnm, lat, lon, outFnm);
    if (hasSucceeded) {
      System.out.println("\nGPS data saved\n");
      showGPS(outFnm);
    }
    else
      System.out.println("\nGPS data not saved\n");
  }  // end of writeGPS()



  private static String extendFilename(String fnm, String extra)
  // add the 'extra' string to the filename, before its extension
  {
    int sepPosn = fnm.lastIndexOf('.');
    if (sepPosn == -1) {
      System.out.println("No extension found");
      return (fnm+extra);
    }
    else 
      return (fnm.substring(0, sepPosn) + extra + fnm.substring(sepPosn));
  }  // end of extendFilename()


}  // end of GPSTagTests class
