
// MDViewer.java
// Andrew Davison, November 2010, ad@fivedots.coe.psu.ac.th

/* Demonstrate various ways of listing the metadata stored in 
   EXIF format in a JPEG or TIFF file by 
   using Sanselan (http://commons.apache.org/sanselan/)
   and my support classes, MetaDataUtils and GeoMath

   I used XnView (http://www.xnview.com) to check the EXIF 
   data inside JPEG files separately from this code.

   Usage:
     > run MDViewer engSign.java
*/

import java.util.ArrayList;

import org.apache.sanselan.formats.jpeg.JpegImageMetadata;
import org.apache.sanselan.formats.tiff.constants.*;
import org.apache.sanselan.formats.tiff.TiffField;


public class MDViewer
{

  public static void main(String[] args) 
  {
    if (args.length != 1) {
      System.out.println("Usage: run MDViewer <jpg file>");
      return;
    }

    JpegImageMetadata jpegMD = MetaDataUtils.getJpegMD(args[0]);
    if (jpegMD == null)
      return;

    // Jpeg EXIF metadata is stored in a TIFF-based directory structure
    // and is identified by TIFF tags.
    // See Sanselan's TiffConstants class for a list of TIFF tags.

    System.out.println("\nVarious EXIF tags:");
    printTag(jpegMD, TiffConstants.TIFF_TAG_XRESOLUTION);
    printTag(jpegMD, TiffConstants.TIFF_TAG_DATE_TIME);
    printTag(jpegMD, TiffConstants.EXIF_TAG_DATE_TIME_ORIGINAL);
    printTag(jpegMD, TiffConstants.EXIF_TAG_CREATE_DATE);
    printTag(jpegMD, TiffConstants.EXIF_TAG_ISO);
    printTag(jpegMD, TiffConstants.EXIF_TAG_SHUTTER_SPEED_VALUE);
    printTag(jpegMD, TiffConstants.EXIF_TAG_APERTURE_VALUE);
    printTag(jpegMD, TiffConstants.EXIF_TAG_BRIGHTNESS_VALUE);

    System.out.println("\nGPS-related EXIF tags:");
    printTag(jpegMD, TiffConstants.GPS_TAG_GPS_LATITUDE_REF);
    printTag(jpegMD, TiffConstants.GPS_TAG_GPS_LATITUDE);
    printTag(jpegMD, TiffConstants.GPS_TAG_GPS_LONGITUDE_REF);
    printTag(jpegMD, TiffConstants.GPS_TAG_GPS_LONGITUDE);
    System.out.println();

    showItems(jpegMD);
  }  // end of main()



  private static void printTag(JpegImageMetadata jpegMD, TagInfo tagInfo)
  {
    TiffField field = jpegMD.findEXIFValue(tagInfo);
    if (field == null)
      System.out.println(tagInfo.name + ": not found");
    else
      System.out.println(tagInfo.name + ": " + field.getValueDescription());
  }  // end of printTag()



  private static void showItems(JpegImageMetadata jpegMD)
  {
    System.out.println("Metadata Items:");
    ArrayList items = jpegMD.getItems();
    for (int i = 0; i < items.size(); i++)
      System.out.println("  " + items.get(i));
  }  // end of showItems()


}  // end of MDViewer class
