
// ShowMap.java
// Andrew Davison, November 2010, ad@fivedots.coe.psu.ac.th

/* The user supplies a latitude and longitude, which are displayed
   on a map downloaded from OpenStreetMap (http://www.openstreetmap.org/).

   This is managed by a JMapViewer Swing component, which
   is a subclass of JPanel. JMapViewer is explained at
   http://wiki.openstreetmap.org/wiki/JMapViewer.

   This code is a simplified version of Demo.java by Jan Peter Stotz
   in the JMapViewer download 
   (http://svn.openstreetmap.org/applications/viewer/jmapviewer).
   
   Usage:
      run ShowMap 7.006835 100.5020
                // Robot building
      run ShowMap 7.001135 100.491960
                // Oak Tree Bakery
      run ShowMap 53.314401 -2.255305
                // UK address

    Use Google maps with lat, lon to check positions.
*/

import java.awt.*;
import javax.swing.*;
import org.openstreetmap.gui.jmapviewer.*;



public class ShowMap extends JFrame 
{
   // Robot building is the default position
  private static final double LAT_DEFAULT = 7.006835; 
  private static final double LONG_DEFAULT = 100.5020;


  public ShowMap(double lat, double lon) 
  {
    super("Show Map");

    Container c = getContentPane();
    c.setLayout( new BorderLayout() );

    JMapViewer map = new JMapViewer();    // map panel, default size is 400x400
    c.add(map, BorderLayout.CENTER);

    JLabel helpLabel = new JLabel("<html>Use right mouse button to move,<br> " +
                                  "left double click or mouse wheel to zoom.", 
                                      JLabel.CENTER);
    helpLabel.setFont(new Font("Serif", Font.PLAIN, 18));
    c.add(helpLabel, BorderLayout.SOUTH);

    // use a position marker to center the map
    map.addMapMarker(new MapMarkerDot(lat, lon));
    map.setDisplayToFitMapMarkers();
    map.setZoom(17);  // so roads are visible

    setDefaultCloseOperation( JFrame.EXIT_ON_CLOSE );
    pack();
    // setResizable(false); 
    setVisible(true);
  }  // end of ShowMap()


  // -------------------------------------------------


  public static void main(String[] args) 
  {  
    double lat = LAT_DEFAULT;
    double lon = LONG_DEFAULT;
    if (args.length !=2)
      System.err.println("Usage: run ShowMap [ latitude longitude ]");
    else {
      lat = Double.parseDouble(args[0]);
      lon  = Double.parseDouble(args[1]);
    }
    System.out.printf("Using (lat, long): (%.6f, %.6f)\n", lat, lon);
    new ShowMap(lat, lon);  
  } // end of main()

}  // end of ShowMap class
